From: "Theodore Ts'o" <tytso@mit.edu>
To: Jens Axboe <jens.axboe@oracle.com>
Cc: linux-kernel@vger.kernel.org
Subject: What happened to this patch? (Re: [BUG] panic after umount (biscted))
Date: Thu, 13 Dec 2007 19:38:44 -0500 [thread overview]
Message-ID: <E1J2yZg-0004aQ-Rn@closure.thunk.org> (raw)
I was going through my set of kernel patches that I've cherry picked on
LKML for my private kernel, and I noticed this hasn't gotten merged into
mainline yet. The original thread was here:
http://lkml.org/lkml/2007/10/27/61
and addressed a panic after a umount reported by Sebastian Siewior. Was
this addressed in some other way?
- Ted
diff --git a/drivers/scsi/scsi_lib.c b/drivers/scsi/scsi_lib.c
index 61fdaf0..4042269 100644
--- a/drivers/scsi/scsi_lib.c
+++ b/drivers/scsi/scsi_lib.c
@@ -1115,6 +1115,8 @@ static int scsi_init_io(struct scsi_cmnd *cmd)
* kmapping pages)
*/
cmd->use_sg = req->nr_phys_segments;
+ if (!cmd->use_sg)
+ return 0;
/*
* If sg table allocation fails, requeue request later.
@@ -1191,7 +1193,7 @@ int scsi_setup_blk_pc_cmnd(struct scsi_device *sdev, struct request *req)
if (req->bio) {
int ret;
- BUG_ON(!req->nr_phys_segments);
+ BUG_ON(!req->nr_phys_segments && req->bio->bi_size);
ret = scsi_init_io(cmd);
if (unlikely(ret))
@@ -1236,9 +1238,11 @@ int scsi_setup_fs_cmnd(struct scsi_device *sdev, struct request *req)
if (ret != BLKPREP_OK)
return ret;
/*
* Filesystem requests must transfer data.
*/
- BUG_ON(!req->nr_phys_segments);
+ if (!req->nr_phys_segments && !bio_empty_barrier(req->bio))
+ blk_dump_rq_flags(req, "scsi");
cmd = scsi_get_cmd_from_req(sdev, req);
if (unlikely(!cmd))
next reply other threads:[~2007-12-14 0:39 UTC|newest]
Thread overview: 2+ messages / expand[flat|nested] mbox.gz Atom feed top
2007-12-14 0:38 Theodore Ts'o [this message]
2007-12-14 8:03 ` What happened to this patch? (Re: [BUG] panic after umount (biscted)) Jens Axboe
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=E1J2yZg-0004aQ-Rn@closure.thunk.org \
--to=tytso@mit.edu \
--cc=jens.axboe@oracle.com \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1236,9 +1238,11 @@ int scsi_setup_fs_cmnd(struct scsi_device *sdev, struct request *req)
return ret;
/*
- * Filesystem requests must transfer data.
+ * Filesystem requests must transfer data, unless it's an empty
+ * barrier.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox